==> pyobjc-framework-Cocoa-3.0.1.tar.gz: pyobjc-framework-Cocoa-3.0.1/PyObjCTest/test_nsconnection.py <==
from PyObjCTools.TestSupport import *

from Foundation import *

try:
    unicode
except NameError:
    unicode = str

class TestNSConnectionHelper (NSObject):
    def makeNewConnection_sender_(self, a, b): return 1
    def connection_shouldMakeNewConnection_(self, a, b): return 1
    def authenticateComponents_withData_(self, a, b): return 1
    def connection_handleRequest_(self, a, b): return 1

class TestNSConnection (TestCase):
    def testConstants(self):
        self.assertIsInstance(NSConnectionReplyMode, unicode)
        self.assertIsInstance(NSConnectionDidDieNotification, unicode)
        self.assertIsInstance(NSFailedAuthenticationException, unicode)
        self.assertIsInstance(NSConnectionDidInitializeNotification, unicode)

    def testMethods(self):
        self.assertArgIsBOOL(NSConnection.setIndependentConversationQueueing_, 0)
        self.assertResultIsBOOL(NSConnection.independentConversationQueueing)
        self.assertResultIsBOOL(NSConnection.isValid)
        self.assertResultIsBOOL(NSConnection.registerName_)
        self.assertResultIsBOOL(NSConnection.registerName_withNameServer_)
        self.assertResultIsBOOL(NSConnection.multipleThreadsEnabled)

    def testProtocols(self):
        self.assertResultIsBOOL(TestNSConnectionHelper.makeNewConnection_sender_)
        self.assertResultIsBOOL(TestNSConnectionHelper.connection_shouldMakeNewConnection_)
        self.assertResultIsBOOL(TestNSConnectionHelper.authenticateComponents_withData_)
        self.assertResultIsBOOL(TestNSConnectionHelper.connection_handleRequest_)

if __name__ == "__main__":
    main()

==> pyobjc-framework-Cocoa-5.3.tar.gz: pyobjc-framework-Cocoa-5.3/PyObjCTest/test_nsconnection.py <==
from PyObjCTools.TestSupport import *

from Foundation import *

class TestNSConnectionHelper (NSObject):
    def makeNewConnection_sender_(self, a, b): return 1
    def connection_shouldMakeNewConnection_(self, a, b): return 1
    def authenticateComponents_withData_(self, a, b): return 1
    def connection_handleRequest_(self, a, b): return 1

class TestNSConnection (TestCase):
    def testConstants(self):
        self.assertIsInstance(NSConnectionReplyMode, unicode)
        self.assertIsInstance(NSConnectionDidDieNotification, unicode)
        self.assertIsInstance(NSFailedAuthenticationException, unicode)
        self.assertIsInstance(NSConnectionDidInitializeNotification, unicode)

    def testMethods(self):
        self.assertArgIsBOOL(NSConnection.setIndependentConversationQueueing_, 0)
        self.assertResultIsBOOL(NSConnection.independentConversationQueueing)
        self.assertResultIsBOOL(NSConnection.isValid)
        self.assertResultIsBOOL(NSConnection.registerName_)
        self.assertResultIsBOOL(NSConnection.registerName_withNameServer_)
        self.assertResultIsBOOL(NSConnection.multipleThreadsEnabled)

    def testProtocols(self):
        self.assertResultIsBOOL(TestNSConnectionHelper.makeNewConnection_sender_)
        self.assertResultIsBOOL(TestNSConnectionHelper.connection_shouldMakeNewConnection_)
        self.assertResultIsBOOL(TestNSConnectionHelper.authenticateComponents_withData_)
        self.assertResultIsBOOL(TestNSConnectionHelper.connection_handleRequest_)

    @min_sdk_level('10.10')
    def testProtocolObjects(self):
        objc.protocolNamed('NSConnectionDelegate')

if __name__ == "__main__":
    main()
